@@ -530,7 +530,7 @@ private:
 #endif
 
 public:
-  Lum::OS::Mutex           dataMutex;
+  Lum::OS::RWMutex         dataMutex;
   GPSData                  data;
 
 private:
@@ -544,13 +544,6 @@ private:
     return textValue;
   }
 
-  void UpdateConnectionStatus()
-  {
-    Lum::OS::Guard<Lum::OS::Mutex> guard(dataMutex);
-
-    data.SetConnected(gpsData!=NULL);
-  }
-
   void InitializeGPS()
   {
     std::cout << "Initialize GPS..." << std::endl;
@@ -574,8 +567,6 @@ private:
     else {
       std::cout << "GPS NOT initialized: " << errno << std::endl;
     }
-
-    UpdateConnectionStatus();
 #endif
   }
 
@@ -599,9 +590,6 @@ private:
     g_object_unref(control);
     control=NULL;
 #endif
-
-    UpdateConnectionStatus();
-
     std::cout << "GPS deinitialized!" << std::endl;
   }
 
@@ -629,8 +617,6 @@ private:
       data.SetConnected(false);
       std::cout << "GPS NOT initialized: " << errno << std::endl;
     }
-
-    UpdateConnectionStatus();
 #endif
   }
 
@@ -748,7 +734,7 @@ public:
 
   void GetGPSDataCopy(GPSData& data)
   {
-    Lum::OS::Guard<Lum::OS::Mutex> guard(dataMutex);
+    Lum::OS::ReadGuard<Lum::OS::RWMutex> guard(dataMutex);
 
     data=this->data;
   }
@@ -1057,9 +1043,9 @@ static void cb(struct gps_data_t* data, char * buf, size_t len, int level)
 {
   assert(window!=NULL);
 
-  Lum::OS::Guard<Lum::OS::Mutex> guard(window->dataMutex);
+  Lum::OS::WriteGuard<Lum::OS::RWMutex> guard(window->dataMutex);
 
-  GPSData                        &gpsData=window->data;
+  GPSData                               &gpsData=window->data;
 
   gpsData.SetConnected(true);
 
